@@ -14,8 +14,8 @@ boardelement editorload_objects[XYE_HORZ][XYE_VERT];
 int editorload_xyex;
 int editorload_xyey;
 
-int editorload_portal_x[5][2];
-int editorload_portal_y[5][2];
+int editorload_portal_x[XYE_OBJECT_COLORS+1][2];
+int editorload_portal_y[XYE_OBJECT_COLORS+1][2];
 int editorload_defaultwall = 0;
 
 string editor::loadError;
@@ -169,9 +169,16 @@ editorcolor getElementColor(TiXmlElement* el)
     string v=ptr;
     
     if (v.length() >= 1) {
-        if(v[0]=='R') return EDCO_RED;
-        else if (v[0]=='G') return EDCO_GREEN;
-        else if (v[0]=='B') return EDCO_BLUE;
+        switch(v[0]) {
+        case 'R': case 'r':
+            return EDCO_RED;
+        case 'G': case 'g':
+            return EDCO_GREEN;
+        case 'B': case 'b':
+            return EDCO_BLUE;
+        case 'P': case 'p':
+            return EDCO_PURPLE;            
+        }
     }
  return EDCO_YELLOW;
 }
@@ -212,7 +219,7 @@ bool editor_LoadStar(TiXmlElement* el)
 
     boardelement &o=editorload_objects[x][y];
     o.type=EDOT_GEM;
-    o.color = EDCO_WHITE;
+    o.color = EDCO_PURPLE;
     return true;
 }
 
@@ -573,11 +580,17 @@ bool editor_LoadPortal(TiXmlElement * el)
 
     int defcolor=-1;
     el->QueryIntAttribute("defcolor", &defcolor);
-    if ( (defcolor<0) || (defcolor>=5) )
+    if ( (defcolor<0) || (defcolor>=XYE_OBJECT_COLORS+1) )
     {
         defcolor  = 0;
         loadPortalIssue = true;
         cout<< "Notice: A <portal> tag had a strange/missing defcolor value. This could indicate that the level was not made by this version of the editor."<<endl;
+    } else {
+        if (defcolor == 4) {
+            defcolor = 5;
+        } else if (defcolor == 5) {
+            defcolor = 4;
+        }
     }
     if( editorload_portal_x[defcolor][0] == -1)
     {
@@ -1265,8 +1278,13 @@ bool editor_LoadFloor(TiXmlElement* el)
         if (v=="area") {
             int x1=400,x2=400,y1=400,y2=400;
             ch->QueryIntAttribute("x1",&x1);
-            ch->QueryIntAttribute("x2",&x2);
             ch->QueryIntAttribute("y1",&y1);
+            if (x1==400) {
+                ch->QueryIntAttribute("x",&x1);
+                ch->QueryIntAttribute("y",&y1);
+            }
+
+            ch->QueryIntAttribute("x2",&x2);
             ch->QueryIntAttribute("y2",&y2);
             if (x1 != 0 || x2 != 29 || y1 != 0 || y2 != 19 ) {
                 return true;
@@ -1294,6 +1312,12 @@ void editorload_loadKyeLevel(const KyeLevel& klv)
     editor::board->solution = "";
     editor::board->xye_x = 0;
     editor::board->xye_y = 0;
+    for (int i=0; i<TOTAL_EDITOR_COLOR_OPTIONS; i++) {
+        DefaultColorData &cd = editor::board->colors[i];
+        cd.useDefault = true;
+    }
+
+    
     for (int i=0;i<XYE_HORZ;i++)for (int j=0;j<XYE_VERT;j++)
     {
         loadKyeChar( klv.data[i][j], editor::board->objects[i][XYE_VERT - j - 1], i );
@@ -1302,7 +1326,7 @@ void editorload_loadKyeLevel(const KyeLevel& klv)
             editor::board->xye_y = XYE_VERT - j - 1;
         }
     }
-    for (int i=0; i<5; i++) {
+    for (int i=0; i<XYE_OBJECT_COLORS+1; i++) {
         for (int j=0; j<2; j++) {
             editor::board->portal_x[i][j] = -1,
             editor::board->portal_y[i][j] = -1;
@@ -1345,7 +1369,7 @@ bool editor::load_KyeFormat(TiXmlElement* el)
     {
         editorload_objects[i][j] = editor::board->objects[i][XYE_VERT-j-1];
     }
-    for (int i=0; i<5; i++) {
+    for (int i=0; i<XYE_OBJECT_COLORS+1; i++) {
         for (int j=0; j<2; j++) {
             editorload_portal_x[i][j] = editor::board->portal_x[i][j],
             editorload_portal_y[i][j] = XYE_VERT-editor::board->portal_y[i][j]-1;
@@ -1357,6 +1381,7 @@ bool editor::load_KyeFormat(TiXmlElement* el)
     return true;
 }
 
+
 bool editor::appendLevels(const string file)
 {
     loadPortalIssue = false;
@@ -1382,6 +1407,7 @@ bool editor::appendLevels(const string file)
         level=pack->FirstChildElement("level");
         bool colorWarn = false;
         bool errorsWarn = false;
+        bool hiddenSolutionWarn = false;
         int tn = 0;
         while(level!=NULL)
         {
@@ -1395,7 +1421,7 @@ bool editor::appendLevels(const string file)
                 editorload_colors[i].useDefault = true;
             }
 
-            for (int i=0; i<5; i++) {
+            for (int i=0; i<XYE_OBJECT_COLORS+1; i++) {
                 for (int j=0; j<2;j++) {
                     editorload_portal_x[i][j] = editorload_portal_y[i][j] = -1;
                 }
@@ -1438,10 +1464,13 @@ bool editor::appendLevels(const string file)
                     const char* gt=el->GetText();
                     lbye= ( (gt!=NULL) ? gt : "");
                 }
-                else if (v=="solution")
+                else if ( (v=="solution") ||(v=="hiddensolution") )
                 {
                     const char* gt=el->GetText();
                     lsolution= ( (gt!=NULL) ? gt : "");
+                    if (v == "hiddensolution") {
+                        hiddenSolutionWarn = true;
+                    }
                 }
                 else if (v=="kyeformat") {
                     if ( ! load_KyeFormat(el) ) {
@@ -1490,7 +1519,7 @@ bool editor::appendLevels(const string file)
             {
                 editor::board->objects[i][XYE_VERT-j-1]=editorload_objects[i][j];
             }
-            for (int i=0; i<5; i++) {
+            for (int i=0; i<XYE_OBJECT_COLORS+1; i++) {
                 for (int j=0; j<2; j++) {
                     editor::board->portal_x[i][j] = editorload_portal_x[i][j],
                     editor::board->portal_y[i][j] = XYE_VERT-editorload_portal_y[i][j]-1;
@@ -1536,6 +1565,9 @@ bool editor::appendLevels(const string file)
             loadError += "Some portal objects used features that are not compatible with the editor. ";
             
         }
+        if (hiddenSolutionWarn) {
+            loadError += "The <hiddensolution> tag is not supported by the editor yet, the hidden solution has been loaded as a normal one. ";
+        }
         cout << "File loaded successfully.\n";
         editorboard::LoadLevelNumber(editor::board, oldn);
         updateCountRelated();
