@@ -15,11 +15,6 @@ Permission is granted to anyone to use this software for any purpose, including
 
 */
 
-//levels.cpp contains the level browser, this is my first experience at GUI development so no wonder it actually
-//blows. It will eventually improve or under the license you can always contribute.
-//
-
-
 #include "xye.h"
 #include "xyedit.h"
 #include "xye_script.h"
@@ -27,6 +22,7 @@ Permission is granted to anyone to use this software for any purpose, including
 #include "skins.h"
 #include "options.h"
 #include "vxsdl.h"
+#include "listbox.h"
 #include<string>
 #include<cstring>
 #include<algorithm>
@@ -36,13 +32,15 @@ using std::sort;
 
 #include "browser.h"
 
-#define levsfolder "levels/"
-//#define levsfolder "levels/kye/charity/"
+
 
 
 namespace LevelBrowser
 {
 
+const char* LEVELS_FOLDER = "levels/";
+
+
 void PlayLevel();
 void OpenEditor();
 void EditLevel();
@@ -52,6 +50,9 @@ window* thewindow;
 button* PlayButton;
 button* EditButton;
 
+listbox* levellistbox;
+
+
 Font* MenuFont;
 Font* MenuSelectedFont;
 Font* InfoFont;
@@ -81,111 +82,6 @@ void LoadActiveFileInfo();
 
 #define SPACING_TEXT "                             "
 
-
-class LevelList: public control
-{
-public:
-
-    LevelList(int sx, int sy, int sw, int sh)
-    {
-        x=sx, y=sy, w=sw, h=sh;
-        
-    }
-    
-    void loop(){}
-    
-    void draw(SDL_Surface* target)
-    {
-        Uint32 back=SDL_MapRGB(target->format, options::LevelMenu_menu);
-        SDL_FillRect(target, x,y,w,h,    back);
-
-        Sint16 cy=y,cx=x+2;
-
-        Uint16 nw,fp=cx+ InfoFont->TextWidth(" ");
-        
-        Uint8 fh=options::GetGridSize();//  game::FontRes->Height();
-        int fof=0;
-        int fohei=InfoFont->Height();
-
-        if(fh<fohei)
-        {
-            fh=InfoFont->Height()+2;
-            fof=1;
-        }
-        else fof=(fh-fohei)/2;
-
-        Uint16 sh=h - fh;
-        //int i=0;
-        int i=0;
-        int fxh= (int)(  (h *0.5) / fh );
-        if (Active>fxh)
-        {
-            i=Active-fxh+1;
-        }
-        nw=w-2;
-        while ((i<FileN) && (cy<sh))
-        {
-            string tm=StripPath( FoundFile[i]  );
-            if (Active==i)
-            {
-
-                SDL_FillRect(target, cx , cy, nw  , fh,
-                    ActiveIsValid?
-                        SDL_MapRGB(target->format, options::LevelMenu_selected):
-                        SDL_MapRGB(target->format, options::LevelMenu_selectederror));
-
-                MenuSelectedFont->Write(target,fp,cy+fof, tm);
-            }
-            else
-                MenuFont->Write(target,fp,cy+fof, tm);
-            i++;
-            cy+=fh;
-        }
-
-        cx=nw+5; cy=30;
-
-
-    }
-    
-    void onMouseMove(int px,int py){}
-    void onMouseOut() {}
-    void onMouseDown(int px,int py) {}
-    
-    
-    void onMouseUp(int px,int py)
-    {
-        //Now get the initial index so we know how to calculate the stuff
-        int i=0;
-        Uint8 fh=game::GRIDSIZE;
-        int fxh= (int)(  (h *0.5) / fh );
-        if (Active>fxh)
-        {
-            i=Active-fxh+1;
-        }
-
-        fxh=fh;
-        int j=i;
-        while (py>fxh)
-        {
-            j++;
-            fxh+=fh;
-        }
-        if (j<FileN)
-        {
-            if (Active==j)
-            {
-                PlayLevel();
-                return;
-            }
-            Active=j;
-            LoadActiveFileInfo();
-        }
-
-
-    }
-    void onMouseRightUp(int px,int py) {}
-};
-
 class LevelInfo: public control
 {
 public:
@@ -300,21 +196,6 @@ bool Akyexyelevel(const char* f)
     // the standard forces xye extension to be lower case.
 }
 
-char* getHomeDir()
-{
-    char* f =getenv("HOME");
-    string tm;
-    if (f)
-    {
-        tm=f;
-        tm+="/.xye/levels/";       
-    }
-    char * fm = new char[tm.length()+1];
-    strcpy(fm, tm.c_str());
-    return fm;
-}
-
-
 unsigned int CountMatchingFiles(const char* nf)
 {
     Folder F(nf);
@@ -343,19 +224,17 @@ unsigned int CountMatchingFiles(const char* nf)
 
 unsigned int CountMatchingFiles()
 {
-    char* nf=options::fixpath(levsfolder);
-    char *hm=getHomeDir();
+    string nf = options::fixpath(LEVELS_FOLDER);
+    string hm = options::GetLevelsHomeFolder();
     unsigned int c;
 
-    if (strlen(hm)==0)
-       c=CountMatchingFiles(nf);
-    else
-       c=CountMatchingFiles(nf)+CountMatchingFiles(hm);
-
-    delete[] hm;
-    delete[] nf;
-
-return(c);
+    c = CountMatchingFiles(nf.c_str());
+    
+    if ( hm.length() != 0 ) {
+       c += CountMatchingFiles(hm.c_str());
+    }
+ 
+    return(c);
 }
 
 void FillArrayWithFilenames(const char* nf, const char* lvp, unsigned int &c)
@@ -443,13 +322,29 @@ struct LevelSorting
     }
 };
 
+bool onItemSelected(listbox* lb)
+{
+    Active = lb->getSelectedIndex();
+    LoadActiveFileInfo();
+    return ActiveIsValid;
+}
+
+void onItemDoubleClick(listbox* lb)
+{
+    if (ActiveIsValid) {
+        PlayLevel();
+    }
+}
+
 void FillArrayWithFilenames()
 {
 
-    char* nf=options::fixpath(levsfolder);
-    Folder F(nf);
+    string nf=options::fixpath(LEVELS_FOLDER);
+    Folder F(nf.c_str() );
 
-    if (! F.Open()) game::Error("cannot find a levels folder");
+    if (! F.Open()) {
+        game::Error("cannot find a levels folder");
+    }
     unsigned int c=0;
     int i;
     const char* N;
@@ -472,10 +367,10 @@ void FillArrayWithFilenames()
     F.Reset();
     while ((c<FileN) && (N=F.NextSubFolder()))
     {
-        char* tm1=new char[strlen(N)+strlen(nf)+2];
-        char* tm2=new char[strlen(N)+2];
+        char* tm1=new char[strlen(N) + nf.length() + 2];
+        char* tm2=new char[strlen(N)+ 2];
 
-        strcpy(tm1,nf);strcat(tm1,N);strcat(tm1,"/");
+        strcpy(tm1,nf.c_str());strcat(tm1,N);strcat(tm1,"/");
         strcpy(tm2,N);strcat(tm2,"/");
 
         //FillArrayWithFilenames(tm1,tm2,c);
@@ -484,25 +379,33 @@ void FillArrayWithFilenames()
         delete[]tm2;
     }
 
-    char * levelsfolder = nf;
+    string levelsfolder = nf;
 
     //Add levels on %home%/.xye/levels
-    nf=getHomeDir();
-    if ((strlen(nf)!=0) && c) FillArrayWithFilenames(nf,nf,c);
-    delete[] nf;
+    nf = options::GetLevelsHomeFolder();
+    if ((nf.length()!=0) && c) {
+        FillArrayWithFilenames(nf.c_str(),nf.c_str(),c);
+    }
+
 
      //sort the array alphabetically
-    sort(FoundFile, FoundFile+c, LevelSorting(levelsfolder) );
-    delete[] levelsfolder;
-
+    sort(FoundFile, FoundFile+c, LevelSorting(levelsfolder.c_str()) );
+    
+    Active    =0;
     //Finally find the value of res and if someone has it, make sure Active points to it
-    for (i=0;i<c;i++)
+    for (i=0;i<c;i++) {
         if (FoundFile[i]==CurrentFileName)
         {
             Active=i;
-            return;
         }
-    Active    =0;
+    }
+
+    //Add the files to the listbox
+    for (i=0;i<c;i++) {
+        levellistbox->addItem(StripPath(FoundFile[i]), FoundFile[i]);
+    }
+    
+    levellistbox->selectItem(Active);
 
 }
 
@@ -512,8 +415,8 @@ void LoadActiveFileInfo()
     
     ActiveIsValid= LevelPack::GetFileData(fl.c_str(),FileAuthor,FileDesc,FileTitle,FileLevelsN);
     
-    
-    ActiveIsEditable= ActiveIsValid && (fl.substr(0,editor::myLevelsPath.size()) == editor::myLevelsPath);
+    string mylevs = options::GetMyLevelsFolder();
+    ActiveIsEditable= ActiveIsValid && (fl.substr(0, mylevs.size()) == mylevs);
     string flext = "";
     flext = fl.substr(fl.length()-4);
     ActiveIsEditable= ActiveIsEditable && (flext==".xye" ||flext==".kye" ||flext==".KYE");
@@ -528,7 +431,8 @@ void LoadActiveFileInfo()
 void EditFile()
 {
     CurrentFileName = FoundFile[Active];
-    editor::SetFile(editor::myLevelsPath,CurrentFileName.substr(editor::myLevelsPath.size() ) );
+    string mylevs= options::GetMyLevelsFolder();
+    editor::SetFile(mylevs, CurrentFileName.substr(mylevs.size() ) );
     thewindow->SetTransition(editor::StartSection);
 /*        string commandline=options::ExecutablePath;
         commandline+=" --edit ";
@@ -546,8 +450,9 @@ void EditFile()
 
 void OpenEditor()
 {
-    CurrentFileName = editor::myLevelsPath+"editortest.xye";
-    editor::SetFile(editor::myLevelsPath,"editortest.xye");
+    string mylevs = options::GetMyLevelsFolder();
+    CurrentFileName = mylevs+"editortest.xye";
+    editor::SetFile(mylevs, "editortest.xye");
     thewindow->SetTransition(editor::StartSection);
 /*        string commandline=options::ExecutablePath;
         commandline+=" --edit editortest.xye ";
@@ -573,7 +478,6 @@ void onKeyDown(SDLKey keysim, Uint16 unicode)
 {
 }
 
-
 void attemptEditFile()
 {
     if(ActiveIsEditable)
@@ -582,20 +486,6 @@ void attemptEditFile()
     }
 }
 
-bool IsCharKeyEvent(SDLKey& k,char & a,char &b)
-{
-
-    a='\0';
-    if ((k >= SDLK_a) && (k<=SDLK_z))
-    {
-        a= 'a'+(k-SDLK_a);
-        b = 'A'+(k-SDLK_a);
-    }
-    else if ((k >= SDLK_0) && (k<=SDLK_9))
-        a='0'+(k-SDLK_0);
-    return (a!='\0');
-}
-
 void OnSkinButtonClick(const buttondata* data)
 {
     thewindow->SetTransition(SkinBrowser::StartSection);
@@ -606,60 +496,31 @@ void OnWelcomeSkinButtonClick(bool x)
 }
 
 
+
+void OnPlayButtonClick(const buttondata* data)
+{
+    PlayLevel();
+}
+void OnEditorButtonClick(const buttondata* data)
+{
+    OpenEditor();
+}
+void OnEditButtonClick(const buttondata* data)
+{
+    attemptEditFile();
+}
+
+
+void OnQuitButtonClick(const buttondata* data)
+{
+    thewindow->Close();
+}
+
 void onKeyUp(SDLKey keysim, Uint16 unicode)
 {
-    char a='\0',b=a;
-
-    if (IsCharKeyEvent(keysim,a,b))
-    {
-        int l=Active;
-        int i=Active+1;
-        string fn;
-        while (i!=Active)
-        {
-            if (i==FileN) i=0;
-            fn = StripPath(FoundFile[i]);
-            if (  (fn.length()>0) && ((fn[0]==a) || (fn[0]==b)) )
-            {
-                Active=i;
-            }
-            else
-                i++;
-        }
-        LoadActiveFileInfo();
-        return;
-    }
-
-
+    levellistbox->onKeyUp(keysim, unicode);
     switch (keysim)
     {
-
-        case(SDLK_UP):
-            Active--;
-            if (Active<0) Active=FileN-1;
-            LoadActiveFileInfo();
-
-            break;
-        case(SDLK_DOWN):
-
-            Active++;
-            if (Active>=FileN) Active=0;
-            LoadActiveFileInfo();
-            break;
-
-        case(SDLK_PAGEUP):
-            Active-=10;
-            if (Active<0) Active=FileN-1;
-            LoadActiveFileInfo();
-
-            break;
-        case(SDLK_PAGEDOWN):
-
-            Active+=10;
-            if (Active>=FileN) Active=0;
-            LoadActiveFileInfo();
-            break;
-
         case(SDLK_F1):
              OpenEditor();
              //return false;
@@ -686,25 +547,8 @@ void onKeyUp(SDLKey keysim, Uint16 unicode)
 
 }
 
-void OnPlayButtonClick(const buttondata* data)
-{
-    PlayLevel();
-}
-void OnEditorButtonClick(const buttondata* data)
-{
-    OpenEditor();
-}
-void OnEditButtonClick(const buttondata* data)
-{
-    attemptEditFile();
-}
 
 
-void OnQuitButtonClick(const buttondata* data)
-{
-    thewindow->Close();
-}
-
 
 
 void Show()
@@ -715,8 +559,10 @@ void Show()
 
     
     if (FoundFile!=NULL) delete[] FoundFile;
-    FileN=CountMatchingFiles();
-    if (! FileN) game::Error("No level files found");
+    FileN = CountMatchingFiles();
+    if (! FileN) { 
+        game::Error("No level files found");
+    }
     FoundFile= new string[FileN];
     FillArrayWithFilenames();
 
@@ -742,8 +588,21 @@ void StartSection(window* wind)
     thewindow = wind;
     wind->SetCaption("Xye - Select a level file");
     Sint16 lw = 2+game::FontRes->TextWidth(SPACING_TEXT);
-    LevelList* ll = new LevelList(0,0, lw , wind->Height);
+    
+    listbox* ll = listbox::makeNew(0,0,lw, wind->Height);
+    levellistbox = ll;
+    ll->NormalFont = MenuFont;
+    ll->SelectedFont = MenuSelectedFont;
+    ll->BackgroundColor = options::LevelMenu_menu;
+    ll->SelectedColor = options::LevelMenu_selected;
+    ll->InvalidColor = options::LevelMenu_selectederror;
+    ll->BarColor = options::LevelMenu_info;
+    ll->onSelect = onItemSelected;
+    ll->onItemDoubleClick = onItemDoubleClick;
     ll->depth= 1;
+    wind->addControl(ll);
+    
+    
     LevelInfo* li = new LevelInfo(lw, 0, wind->Width-lw, wind->Height);
     li->depth= 2;
     
@@ -800,10 +659,9 @@ void StartSection(window* wind)
     wind->addControl(but);
     
     //...    
-    wind->addControl(ll);
     wind->addControl(li);
-    wind->onKeyUp = onKeyUp;
     wind->onKeyDown = onKeyDown;
+    wind->onKeyUp = onKeyUp;
     wind->onExitAttempt = onExitAttempt;
     
     if (! options::HasConsciouslyChosenTheme() ) {
