@@ -1099,9 +1099,14 @@ void PerformLevelFileSave()
 
 
 
-string GetSkinFile()
+string GetSkinFile(bool stripPath)
 {
-    return StripPath(currentSkinFile);
+    if (stripPath) {
+        return StripPath(currentSkinFile);
+    } else {
+        return currentSkinFile;
+    }
+    
 }
 void SaveConfigFile()
 {
@@ -1154,7 +1159,6 @@ void LoadLevelFile()
     } else {
         path = Dir + "/savedgames.conf";
     }
-    cout << "{{{{{{{"<<endl;
     file.open (path.c_str(), std::ios::in );
     if ( file.is_open())
     {
