@@ -41,8 +41,10 @@ enum blockcolor
     B_YELLOW=0,
     B_RED=1,
     B_BLUE=2,
-    B_GREEN=3
+    B_GREEN=3,
+    B_PURPLE=4
 };
+const int XYE_OBJECT_COLORS = 5;
 enum roundcorner { RC_1,RC_7,RC_9,RC_3 };
 
 typedef blockcolor gemtype;
@@ -351,6 +353,7 @@ class wall : public obj
      static void ResetDefaults();
      static wall* find(char sx, char sy, unsigned char kind = 6);
      void IntelligentUpdateCorners(wall *by);
+     static int GetDefaultVariationVulnerableToFire();
 };
 
 
@@ -359,8 +362,8 @@ class windowblock : public obj
 {
  private:
      blockcolor bc;
-     static unsigned int count[4];
-     static unsigned int activeN[4];
+     static unsigned int count[XYE_OBJECT_COLORS];
+     static unsigned int activeN[XYE_OBJECT_COLORS];
      void OnDeath() { count[bc]--;  if (active) activeN[bc]--; }
      unsigned int anim;
      bool active;
@@ -791,7 +794,7 @@ class toggle : public obj
      blockcolor c;
      bool round;
      bool kind;
-     static bool State[4];
+     static bool State[XYE_OBJECT_COLORS];
      static Uint32 ChangeTic;
      Uint32 Updated;
      void OnDeath() {}
@@ -1023,7 +1026,7 @@ class key : public obj
  private:
 
      void OnDeath() {}
-     static unsigned int Got[4];
+     static unsigned int Got[XYE_OBJECT_COLORS];
 
  public:
      key(square* sq,blockcolor color);
@@ -1037,7 +1040,7 @@ class key : public obj
      static void UseKey(blockcolor ofcolor);
      static void ResetCounts();
      static bool GotKey(blockcolor ofcolor);
-     static bool GetXyesKeys(unsigned int &yl,unsigned int &rd,unsigned int &bl,unsigned int &gr);
+     static bool GetXyesKeys(unsigned int &yl,unsigned int &rd,unsigned int &bl,unsigned int &gr, unsigned int &pr);
 
 };
 
@@ -1069,7 +1072,7 @@ class gem : public obj
      bool anim;
      gemtype gemkind;
      void OnDeath() {}
-     static unsigned int count[5];
+     static unsigned int count[XYE_OBJECT_COLORS+1];
  public:
      gem(square* sq, gemtype t);
      void Draw(unsigned int x, unsigned int y);
@@ -1150,8 +1153,8 @@ class marked: public gobj
      bool active;
      unsigned char anim;
      void OnDeath();
-     static unsigned int count[4];
-     static unsigned int activeN[4];
+     static unsigned int count[XYE_OBJECT_COLORS];
+     static unsigned int activeN[XYE_OBJECT_COLORS];
 
 
     public:
@@ -1331,6 +1334,12 @@ class gameboard : public control
 
 class gamepanel;
 
+enum recordingmode
+{
+    RECORDING_MODE_MOVIE,
+    RECORDING_MODE_BACKGROUND
+};
+
 /**class game*/
 class game
 {
@@ -1409,7 +1418,8 @@ class game
     static bool EvalDirGrid(Uint16 x1,Uint16 y1,Uint16 x2,Uint16 y2,edir &dir);
     static bool EvalDirGrid(obj* object,Uint16 x2,Uint16 y2,edir &dir);
     static bool cameraon;
-    static bool playingrec;
+    static bool          PlayingRecording;
+    static recordingmode RecordingMode;
     static bool undo;
     
     static void onKeyUp(SDLKey keysim, Uint16 unicode);
